"use strict";

exports.__esModule = true;
exports.default = buildQuery;

var _core = require("@superset-ui/core");

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

const PERCENTILE_REGEX = /(\d+)\/(\d+) percentiles/;

function buildQuery(formData) {
  const {
    whiskerOptions,
    columns,
    groupby,
    metrics: formDataMetrics
  } = formData; // TODO: Refactor superset-ui-cre/query and remove QueryFormResidual types which are causing confusion
  // @ts-ignore

  const metrics = formDataMetrics.map(metric => (0, _core.convertMetric)(metric).label);
  return (0, _core.buildQueryContext)(formData, baseQueryObject => {
    let whiskerType;
    let percentiles;
    const percentileMatch = PERCENTILE_REGEX.exec(whiskerOptions);
    const distributionColumns = columns || [];
    if (whiskerOptions === 'Tukey') whiskerType = 'tukey';else if (whiskerOptions === 'Min/max (no outliers)') whiskerType = 'min/max';else if (percentileMatch) {
      whiskerType = 'percentile';
      percentiles = [parseInt(percentileMatch[1], 10), parseInt(percentileMatch[2], 10)];
    } else {
      throw new Error("Unsupported whisker type: " + whiskerOptions);
    }
    return [_extends({}, baseQueryObject, {
      is_timeseries: distributionColumns.length === 0,
      groupby: (groupby || []).concat(distributionColumns),
      post_processing: [{
        operation: 'boxplot',
        options: {
          whisker_type: whiskerType,
          percentiles,
          groupby,
          metrics
        }
      }]
    })];
  });
}